@@ -1,9 +1,13 @@
+
+#=================================
 package SNMP::Effective::Dispatch;
+#=================================
 
 use strict;
 use warnings;
+use Time::HiRes qw/usleep/;
 
-our $VERSION = '1.05';
+our $VERSION = '1.04';
 our %METHOD  = (
     get     => 'get',
     getnext => 'getnext',
@@ -12,66 +16,86 @@ our %METHOD  = (
 );
 
 
-sub _set {
+sub _set { #==================================================================
+
+    ### init
     my $self     = shift;
     my $host     = shift;
     my $request  = shift;
     my $response = shift;
 
+    ### timeout
     return $self->_end($host, 'Timeout') unless(ref $response);
 
+    ### handle response
     for my $r (grep { ref $_ } @$response) {
         my $cur_oid = SNMP::Effective::make_numeric_oid($r->name);
         $host->data($r, $cur_oid);
     }
 
+    ### the end
     return $self->_end($host);
 }
 
-sub _get {
+sub _get { #==================================================================
+
+    ### init
     my $self     = shift;
     my $host     = shift;
     my $request  = shift;
     my $response = shift;
 
+    ### timeout
     return $self->_end($host, 'Timeout') unless(ref $response);
 
+    ### handle response
     for my $r (grep { ref $_ } @$response) {
         my $cur_oid = SNMP::Effective::make_numeric_oid($r->name);
         $host->data($r, $cur_oid);
     }
 
+    ### the end
     return $self->_end($host);
 }
 
-sub _getnext {
+sub _getnext { #==============================================================
+
+    ### init
     my $self     = shift;
     my $host     = shift;
     my $request  = shift;
     my $response = shift;
 
+    ### timeout
     return $self->_end($host, 'Timeout') unless(ref $response);
 
+    ### handle response
     for my $r (grep { ref $_ } @$response) {
         my $cur_oid = SNMP::Effective::make_numeric_oid($r->name);
         $host->data($r, $cur_oid);
     }
 
+    ### the end
     return $self->_end($host);
 }
 
-sub _walk {
+sub _walk { #=================================================================
+
+    ### init
     my $self     = shift;
     my $host     = shift;
     my $request  = shift;
     my $response = shift;
     my $i        = 0;
 
+    ### timeout
     return $self->_end($host, 'Timeout') unless(ref $response);
 
+    ### handle response
     while($i < @$response) {
         my $splice = 2;
 
+        ### handle result
         if(my $r = $response->[$i]) {
             my($cur_oid, $ref_oid) = SNMP::Effective::make_numeric_oid(
                                          $r->name, $request->[$i]->name
@@ -87,34 +111,44 @@ sub _walk {
             }
         }
 
+        ### bad result
         if($splice) {
             splice @$request, $i, 1;
             splice @$response, $i, 1;
         }
     }
 
+    ### to be continued
     if(@$response) {
         $$host->getnext($response, [ \&_walk, $self, $host, $request ]);
         return;
     }
+
+    ### no more to get
     else {
         return $self->_end($host);
     }
 }
 
-sub _end {
+sub _end { #==================================================================
+
+    ### init
     my $self  = shift;
     my $host  = shift;
     my $error = shift;
 
+    ### cleanup
     $self->log->debug("Calling callback for $host...");
     $host->callback->($host, $error);
     $host->clear_data;
 
+    ### the end
     return $self->dispatch($host)
 }
 
-sub dispatch {
+sub dispatch { #==============================================================
+
+    ### init
     my $self     = shift;
     my $host     = shift;
     my $hostlist = $self->hostlist;
@@ -122,10 +156,14 @@ sub dispatch {
     my $request;
     my $req_id;
 
-    $self->_wait_for_lock;
+    ### setup
+    usleep 900 + int rand 200 while($self->_lock);
+    $self->_lock(1);
 
     HOST:
     while($self->{'_sessions'} < $self->max_sessions or $host) {
+
+        ### init
         $host         ||= shift @$hostlist or last HOST;
         $request        = shift @$host     or next HOST;
         $req_id         = undef;
@@ -166,19 +204,23 @@ sub dispatch {
         }
     }
 
-    $log->debug(sprintf "Sessions/max-sessions: %i<%i",
-        $self->{'_sessions'}, $self->max_sessions
+    ### the end
+    $self->_lock(0);
+    $log->debug(
+        "Sessions/max-sessions: "
+       .$self->{'_sessions'} ." < " .$self->max_sessions
     );
     unless(@$hostlist or $self->{'_sessions'}) {
         $log->info("SNMP::finish() is next up");
         SNMP::finish();
     }
 
-    $self->_unlock;
+    ### the end
     return @$hostlist || $self->{'_sessions'};
 }
 
-1;
+#=============================================================================
+1983;
 __END__
 
 =head1 NAME
@@ -187,7 +229,7 @@ SNMP::Effective::Dispatch - Helper module for SNMP::Effective
 
 =head1 VERSION
 
-This document refers to version 1.05 of SNMP::Effective::Dispatch.
+This document refers to version 1.04 of SNMP::Effective::Dispatch.
 
 =head1 DESCRIPTION
 
