@@ -1,4 +1,7 @@
+
+#=============================
 package SNMP::Effective::Host;
+#=============================
 
 use warnings;
 use strict;
@@ -6,7 +9,7 @@ use overload '""'  => sub { shift()->{'_address'} };
 use overload '${}' => sub { shift()->{'_session'} };
 use overload '@{}' => sub { shift()->{'_varlist'} };
 
-our $VERSION = '1.05';
+our $VERSION = '1.04';
 
 
 BEGIN { ## no critic # for strict
@@ -28,10 +31,15 @@ BEGIN { ## no critic # for strict
     }
 }
 
-sub data {
+sub data { #==================================================================
+
+    ### init
     my $self = shift;
 
+    ### save data
     if(@_) {
+        
+        ### init save
         my $r       = shift;
         my $ref_oid = shift || '';
         my $iid     = $r->[1]
@@ -40,42 +48,54 @@ sub data {
 
         $ref_oid    =~ s/^\.//mx;
 
+        ### save
         $self->{'_data'}{$ref_oid}{$iid} = $r->[2];
         $self->{'_type'}{$ref_oid}{$iid} = $r->[3];
     }
 
+    ### the end
     return $self->{'_data'};
 }
 
-sub clear_data {
+sub clear_data { #============================================================
+
+    ### init
     my $self = shift;
 
     $self->{'_data'} = {};
     $self->{'_type'} = {};
 
+    ### the end
     return;
 }
 
-sub arg {
+sub arg { #===================================================================
+
+    ### init
     my $self = shift;
     my $arg  = shift;
 
+    ### set value
     if(ref $arg eq 'HASH') {
         $self->{'_arg'}{$_} = $arg->{$_} for(keys %$arg);
     }
 
-    return %{$self->{'_arg'}}, DestHost => "$self" if(wantarray);
-    return   $self->{'_arg'};
+    ### the end
+    return wantarray ? (%{$self->{'_arg'}}, DestHost => "$self") : ();
 }
 
-sub new {
+sub new { #===================================================================
+    
+    ### init
     my $class = shift;
     my $host  = shift or return;
     my $log   = shift;
     my($session, @varlist);
 
+    ### tie
     tie @varlist, "SNMP::Effective::VarList";
 
+    ### the end
     return bless {
         _address  => $host,
         _log      => $log,
@@ -88,7 +108,8 @@ sub new {
     }, $class;
 }
 
-1;
+#=============================================================================
+1983;
 __END__
 
 =head1 NAME
@@ -97,7 +118,7 @@ SNMP::Effective::Host - Helper module for SNMP::Effective
 
 =head1 VERSION
 
-This document refers to version 1.05 of SNMP::Effective::Host.
+This document refers to version 1.04 of SNMP::Effective::Host.
 
 =head1 DESCRIPTION
 
