@@ -1,4 +1,7 @@
+
+#=================================
 package SNMP::Effective::HostList;
+#=================================
 
 use warnings;
 use strict;
@@ -9,28 +12,29 @@ use overload '@{}' => sub {
                           return \@Array;
                       };
 
-our $VERSION = '1.05';
+our $VERSION = '1.04';
 
 
-sub TIEARRAY {
+sub TIEARRAY { #==============================================================
     return $_[1];
 }
 
-sub FETCHSIZE {
+sub FETCHSIZE { #=============================================================
     return 0 + keys %{$_[0]};
 }
 
-sub SHIFT {
+sub SHIFT { #=================================================================
     my $self = shift;
     my $key  = (keys %$self)[0] or return;
     return delete $self->{$key};
 }
 
-sub new {
+sub new { #===================================================================
     return bless {}, $_[0];
 }
 
-1;
+#=============================================================================
+1983;
 __END__
 
 =head1 NAME
@@ -39,7 +43,7 @@ SNMP::Effective::HostList - Helper module for SNMP::Effective
 
 =head1 VERSION
 
-This document refers to version 1.05 of SNMP::Effective::HostList.
+This document refers to version 1.04 of SNMP::Effective::HostList.
 
 =head1 DESCRIPTION
 
