@@ -1,4 +1,7 @@
+
+#================================
 package SNMP::Effective::VarList;
+#================================
 
 use warnings;
 use strict;
@@ -6,10 +9,12 @@ use SNMP;
 use Tie::Array;
 
 our @ISA     = qw/Tie::StdArray/;
-our $VERSION = '1.05';
+our $VERSION = '1.04';
 
 
-sub PUSH {
+sub PUSH { #==================================================================
+
+    ### init
     my $self = shift;
     my @args = @_;
 
@@ -52,10 +57,12 @@ sub PUSH {
         }
     }
 
+    ### the end
     return $self->FETCHSIZE;
 }
 
-1;
+#=============================================================================
+1983;
 __END__
 
 =head1 NAME
@@ -64,7 +71,7 @@ SNMP::Effective::VarList - Helper module for SNMP::Effective
 
 =head1 VERSION
 
-This document refers to version 1.05 of SNMP::Effective::VarList.
+This document refers to version 1.04 of SNMP::Effective::VarList.
 
 =head1 DESCRIPTION
 
